@@ -29,8 +29,13 @@ emWeights <- function (rpairs, cutoff=0.95,...)
   is_fuzzy=!all(is.element(pairs,0:1))
   if (is_fuzzy)
   {
-      pairs_fuzzy=pairs
-      pairs=as.array((pairs>=cutoff)*1)
+      if(length(cutoff)==1 || length(cutoff)==ncol(pairs)){
+      	pairs_fuzzy=pairs
+      	pairs=as.array((pairs>=cutoff)*1)
+	}
+	else {
+	 stop("Cutoff must be a vector with length equal to the number of attributes or to one!")
+	 }
   }
 
   n_data=nrow(pairs)  
